# dukron

For Xi-Lin's original PSGD repo, see [psgd_torch](https://github.com/lixilinx/psgd_torch).

For JAX versions, see [psgd_jax](https://github.com/evanatyourservice/psgd_jax) and
[distributed_kron](https://github.com/evanatyourservice/distributed_kron).
